@@ -2,7 +2,7 @@
 """
 Define each management command as a separate Python module.
 """
-__author__ = "flanker"
+__author__ = 'Matthieu Gallet'
 # __copyright__ = "Copyright 2013, 19pouces.net"
 # __credits__ = "flanker"
 # __maintainer__ = "flanker"
